@@ -40,7 +40,7 @@ BEGIN
     require Siffra::Base;
     use Exporter ();
     use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-    $VERSION = '0.20';
+    $VERSION = '0.21';
     @ISA     = qw(Siffra::Base Exporter);
 
     #Give a hoot don't pollute, do not export more than needed by default
@@ -456,13 +456,14 @@ sub parseCSV()
 
         Text::CSV_XS->new(
             {
-                binary         => 1,
-                auto_diag      => 0,
-                diag_verbose   => 0,
-                blank_is_undef => 1,
-                empty_is_undef => 1,
-                sep_char       => $sep_char,
-                quote_char     => $quote_char,
+                binary             => 1,
+                auto_diag          => 0,
+                diag_verbose       => 0,
+                blank_is_undef     => 1,
+                empty_is_undef     => 1,
+                allow_loose_quotes => 0,
+                sep_char           => $sep_char,
+                quote_char         => $quote_char,
             }
         );
 
@@ -489,6 +490,7 @@ sub parseCSV()
             #    return;
             #}
         );
+
         my @rows;
         open my $fh, "<:encoding($encoding)", $file or die "$file->{path}: $!";
 
@@ -497,6 +499,7 @@ sub parseCSV()
                 $fh,
                 {
                     detect_bom         => ( $encoding =~ /utf-8/i ) ? 1 : 0,
+                    sep_set            => [ $sep_char ],
                     munge_column_names => sub {
                         uc;
                     }
@@ -504,6 +507,17 @@ sub parseCSV()
             );
         };
 
+        my ( $cde, $str, $pos, $rec, $fld ) = $csv->error_diag();
+        if ( $cde > 0 )
+        {
+            $rec--;
+            undef @rows;
+            $retorno->{ error }   = $cde;
+            $retorno->{ message } = "$str @ rec $rec, pos $pos, field $fld";
+            return $retorno;
+        } ## end if ( $cde > 0 )
+        $retorno->{ header } = \@header;
+
         if ( $originalHeader )
         {
             if ( !$self->validaHeader( originalHeader => $originalHeader, header => \@header ) )
@@ -519,17 +533,6 @@ sub parseCSV()
             }
         } ## end if ( $originalHeader )
 
-        my ( $cde, $str, $pos, $rec, $fld ) = $csv->error_diag();
-        if ( $cde > 0 )
-        {
-            $rec--;
-            undef @rows;
-            $retorno->{ error }   = $cde;
-            $retorno->{ message } = "$str @ rec $rec, pos $pos, field $fld";
-            return $retorno;
-        } ## end if ( $cde > 0 )
-        $retorno->{ header } = \@header;
-
         while ( my $row = $csv->getline( $fh ) )
         {
             push @rows, $row;
